@@ -20,8 +20,11 @@ import string
 
 from MappingField import MappingField
 
-def open_mapping_settings(button, title, getMapping):
-  MappingSettings(title, getMapping())
+def open_mapping_settings(button, title, app):
+  MappingSettings(title, app.getZeeButton().getMapping())
+
+def open_alt_mapping_settings(button, title, app):
+  MappingSettings(title, app.getZeeButton().getAltMapping())
 
 class MappingSettings():
   def __init__(self, title, mapping):
