@@ -68,7 +68,7 @@ class ZeemoteDeviceStruct(Structure):
 
 class ZeemoteScanResultStruct(Structure):
   _fields_ = [("number_of_devices", c_int),
-              ("device", ZeemoteDeviceStruct * 1)]
+              ("device", ZeemoteDeviceStruct * 10)]
 
 getScanResults = zeemoteConf.zeemote_get_scan_results_from_gconf
 getScanResults.restype = POINTER(ZeemoteScanResultStruct)
@@ -108,11 +108,6 @@ class ZeeDiscover():
     gobj.g_type_init()
 
   def getZeemote(self, id):
-    devCount = self.getZeemoteCount()
-    if devCount > 1:
-      ZeemoteScanResultStruct._fields_ = [("number_of_devices", c_int),
-              ("device", ZeemoteDeviceStruct * devCount)]
-      
     result = getScanResults()
 
     confDev = result[0].device[id]
